@@ -12,8 +12,8 @@
 ATA.CI <- function(object, ci.level = 95)
 {
 	ata.output <- object
-		if (class(ata.output)!="ATA"){
-		return("The Input must be 'ATA' object. Please use ATA function to produce 'ATA' object. Calculation of Confidence Intervals of ATA Forecasts will terminate!")
+		if (class(ata.output)!="ata"){
+		return("The Input must be 'ata' object. Please use ATA function to produce 'ata' object. Calculation of Confidence Intervals of ATA Forecasts will terminate!")
 	}
 	ci.alpha <- 1 - (ci.level/100)
 	length_resid <- length(ata.output$residuals[!is.na(ata.output$residuals)])
@@ -24,10 +24,9 @@ ATA.CI <- function(object, ci.level = 95)
 	}
 	std_resid <- sd(ata.output$residual, na.rm=TRUE)
 	ci.value <- sqrt(1:ata.output$h) * abs(ci.ZTvalue) * std_resid
-	tsp_F <- tsp(ata.output$forecast)	
+	tsp_F <- tsp(ata.output$forecast)
 	forecast.lower <- ts(ata.output$forecast - ci.value, frequency = tsp_F[3], start = tsp_F[1])
 	forecast.upper <- ts(ata.output$forecast + ci.value, frequency = tsp_F[3], start = tsp_F[1])
 	my_list <- list("forecast"=ata.output$forecast, "forecast.lower"=forecast.lower, "forecast.upper"=forecast.upper)
 	return(my_list)
 }
- 
\ No newline at end of file
